Index: /trunk/MagicSoft/Mars/mcalib/MCalibrationPix.cc
===================================================================
--- /trunk/MagicSoft/Mars/mcalib/MCalibrationPix.cc	(revision 3827)
+++ /trunk/MagicSoft/Mars/mcalib/MCalibrationPix.cc	(revision 3828)
@@ -133,5 +133,5 @@
 //
 // Return -1, if IsHiGainSaturation()
-// Return -1, if the LoGain Mean is zero or -1. (has not yet been set)
+// Return -1, if the LoGain Mean is smaller than 0.5
 // Return -1, if the HiGain Mean is -1.         (has not yet been set) 
 // Return fHiGainMean / fLoGainMean
@@ -143,5 +143,5 @@
     return -1.;
 
-  if ((fLoGainMean == 0.) || (fLoGainMean == -1.))
+  if (fLoGainMean <= 0.5)
     return -1.;
 
@@ -156,5 +156,5 @@
 //
 // Return -1, if IsHiGainSaturation()
-// Return -1, if the LoGain Mean or its variance is zero or -1. (has not yet been set)
+// Return -1, if the LoGain Mean or its variance is smaller than 0.5 (has not yet been set)
 // Return -1, if the HiGain Mean or its variance is -1.         (has not yet been set) 
 // Return propagated error of GetHiLoMeansDivided()
@@ -166,5 +166,5 @@
     return -1.;
 
-  if ((fLoGainMean == 0.) || (fLoGainMean == -1.))
+  if (fLoGainMean <= 0.5)
     return -1.;
 
@@ -189,5 +189,5 @@
 //
 // Return -1, if IsHiGainSaturation()
 // Return -1, if the LoGain Sigma is zero or -1. (has not yet been set)
 // Return -1, if the HiGain Sigma is -1.         (has not yet been set) 
 // Return fHiGainSigma / fLoGainSigma
@@ -199,5 +199,5 @@
     return -1.;
 
-  if ((fLoGainSigma == 0.) || (fLoGainSigma == -1.))
+  if (fLoGainSigma <= 0.01)
     return -1.;
 
@@ -212,5 +212,6 @@
 //
 // Return -1, if IsHiGainSaturation()
 // Return -1, if the LoGain Sigma or its variance is zero or -1. (has not yet been set)
 // Return -1, if the HiGain Sigma or its variance is -1.         (has not yet been set) 
 // Return propagated error of GetHiLoSigmasDivided()
@@ -222,5 +223,5 @@
     return -1.;
 
-  if ((fLoGainSigma == 0.) || (fLoGainSigma == -1.))
+  if (fLoGainSigma <= 0.01) 
     return -1.;
 
@@ -189,5 +189,5 @@
 //
 // Return -1, if IsHiGainSaturation()
-// Return -1, if the LoGain Sigma is zero or -1. (has not yet been set)
+// Return -1, if the LoGain Sigma is smaller than 0.01 
 // Return -1, if the HiGain Sigma is -1.         (has not yet been set) 
 // Return fHiGainSigma / fLoGainSigma
@@ -212,5 +212,6 @@
 //
 // Return -1, if IsHiGainSaturation()
-// Return -1, if the LoGain Sigma or its variance is zero or -1. (has not yet been set)
+// Return -1, if the LoGain Sigma variance is smaller than 0.
+// Return -1, if the LoGain Sigma is smaller than 0.01
 // Return -1, if the HiGain Sigma or its variance is -1.         (has not yet been set) 
 // Return propagated error of GetHiLoSigmasDivided()
